/*
 * --------------------------------------------
 * YXOO
 * @version  1.0
 * @author   huangyaowu (huangyaowu@corp.netease.com)
 * --------------------------------------------
 */

;(function() {

if (typeof YXOO === 'undefined') {
    YXOO = {};
}
  
(function(yx) {
    // 静态方法
    var pub = {
        'imageSrc': '',
        'desc': ''
    };
    var filterContent = function(str) {
        return str.replace(/\s+/g, '');
    };
    var isImageOK = function(img) {
        if (!img.complete) {
            return false;
        }
        if (typeof img.naturalWidth != 'undefined' && img.naturalWidth < 20) {
            return false;
        }
        return true;
    };
    // 修正URL，有些img.src是没有protocol的
    var fixedURL = function(url) {
        if (url) {
            if ((url.indexOf('http:') == 0) || (url.indexOf('https:') == 0)) {
                return url;
            } else {
                return location.protocol + url + '';
            }
        } else {
            return '';
        }
    };
    // 私有方法
    pub.__getImgSrc = function() {
        var imageNode, imageSrc;
        imageSrc = pub.__getYXShareImage();
        if (imageSrc) {
            return imageSrc;
        }
 
        imageSrc = pub.__getOGImage();
        if (imageSrc) {
            return imageSrc;
        }
 
        imageSrc = pub.__getDataSrcImage();
        if (imageSrc) {
            return imageSrc;
        }
 
        imageSrc = pub.__getDocumentImage();
        if (imageSrc) {
            return imageSrc;
        }
        return imageSrc;
    };
    // 获取yixin-share-image
    pub.__getYXShareImage = function () {
        var imageNode, imageSrc;
        imageNode = document.querySelector('meta[name="yixin-share-image"]');
        if (imageNode) {
            imageSrc = imageNode.getAttribute('content');
        }
        return imageSrc;
    };
    // 获取Open Graph Protocol
    pub.__getOGImage = function () {
        var imageNode, imageSrc;
        imageNode = document.querySelector('meta[property="og:image"]');
        if (imageNode) {
            imageSrc = imageNode.getAttribute('content');
        }
        return imageSrc;
    };
    // 获取data-src image
    pub.__getDataSrcImage = function () {
        var imageSrc;
        var imgs = document.getElementsByTagName('img');
        if (imgs.length == 0) {
            return imageSrc;
        }
 
        for (var i = 0; i < imgs.length; i++) {
            var img = imgs[i];
            if (img.getAttribute('data-src')) {
                imageSrc = img.getAttribute('data-src');
                break;
            }
        }
 
        return imageSrc;
    };
    // 获取document image
    pub.__getDocumentImage = function () {
        var imageSrc;
        var imgs = document.getElementsByTagName('img');
        if (imgs.length == 0) {
            return imageSrc;
        }
 
        var findImg;
        for (var i = 0; i < imgs.length; i++) {
            var img = imgs[i];
            if ((!findImg || findImg.width * findImg.height < img.width * img.height) && img.width > 20 && img.height > 20 && isImageOK(img)) {
                findImg = img;
            }
        }
        if (findImg) {
            imageSrc = findImg.src;
        }
 
        return imageSrc;
    };
    // 获取网页描述
    pub.__getDesc = function() {
        var descNode, desc, innerText;
        desc = pub.__getYXShareDesc();
        if (desc && desc.length > 0) {
            return desc;
        }
 
        desc = pub.__getOGDescription();
        if (desc && desc.length > 0) {
            return desc;
        }
 
        desc = pub.__getDocumentDescription();
        if (desc && desc.length > 0) {
            return desc;
        }
 
        return location.host;
    };
    pub.__getYXShareDesc = function () {
        var descNode, desc;
        descNode = document.querySelector('meta[name="yixin-share-desc"]');
        if (descNode) {
            desc = descNode.getAttribute('content');
        }
        return desc;
    };
    // 获取Open Graph Protocol
    pub.__getOGDescription = function () {
        var descNode, desc;
        descNode = document.querySelector('meta[property="og:description"]');
        if (descNode) {
            desc = descNode.getAttribute('content');
        }
        return desc;
    };
    pub.__getDocumentDescription = function () {
        var descNode, desc;
        // v4.2我们决定不抓取正文了，如果没有description，返回location.host
        descNode = document.querySelector('meta[name="description"]');
        if (descNode) {
            desc = descNode.getAttribute('content');
        }
        return desc;
 
        // 旧版本抓取正文
        //var innerText;
        //innerText = document.body.innerText.substr(0, 100);
        //var _innerText = filterContent(innerText);
        //desc = _innerText.length > 0 ? innerText : location.host;
        //return desc;
    };
    // 公有方法
    pub.getDesc = function() {
        var desc = pub.__getDesc() || pub.desc;
        return desc.substr(0, 100);
    };
    pub.getImgSrc = function() {
        return fixedURL(pub.__getImgSrc()) || pub.imageSrc;
    };
    pub.getTitle = function() {
        return document.title;
    };
 
    yx.util = pub;

})(YXOO);

})();
